@@ -4,6 +4,7 @@ import datetime
 import enum
 import types
 import typing as tp
+from pathlib import Path
 
 from django.db import models
 
@@ -17,8 +18,10 @@ __all__ = ["CreateDjangoModel", "create_django_model"]
 class InspectDataclass:
     dataclass: type
 
-    def extract_meta(self) -> tuple[str | None, list[str] | None]:
-        pk_key, unique_together = None, None
+    def extract_meta(
+        self,
+    ) -> tuple[str | None, list[str] | None, dict[str, dict[str, tp.Any]] | None]:
+        pk_key, unique_together, extra_kwgs = None, None, None
         if hasattr(self.dataclass, "Meta"):
             meta = self.dataclass.Meta  # type: ignore
             if hasattr(meta, "primary_key"):
@@ -27,11 +30,14 @@ class InspectDataclass:
             if hasattr(meta, "unique_together"):
                 unique_together = meta.unique_together
                 assert isinstance(unique_together, list)
+            if hasattr(meta, "extra"):
+                extra_kwgs = meta.extra
+                assert isinstance(extra_kwgs, dict)
 
-        return pk_key, unique_together
+        return pk_key, unique_together, extra_kwgs
 
     def get_identifying_parameter(self) -> set[str]:
-        pk_key, unique_together = self.extract_meta()
+        pk_key, unique_together, _ = self.extract_meta()
         res = set()
         if pk_key is not None:
             res.add(pk_key)
@@ -44,9 +50,9 @@ class InspectDataclass:
 class CreateDjangoModel(InspectDataclass):
     def __post_init__(self) -> None:
         # evaluate the Meta class
-        pk_key, unique_together = self.extract_meta()
+        pk_key, unique_together, extra_kwgs = self.extract_meta()
         # translate fields
-        fields: dict[str, tp.Any] = self.translate_fields(pk_key)
+        fields: dict[str, tp.Any] = self.translate_fields(pk_key, extra_kwgs)
         fields["Meta"] = self.generate_meta(unique_together)
         # pylint: disable=comparison-with-callable
         if self.dataclass.__str__ != object.__str__:  # type: ignore
@@ -56,7 +62,7 @@ class CreateDjangoModel(InspectDataclass):
         BACKEND_LINKER.link(self.dataclass, django_model)
 
     def translate_fields(
-        self, pk_key: str | None
+        self, pk_key: str | None, extra_kwgs: dict[str, dict[str, tp.Any]] | None
     ) -> "dict[str, models.Field[tp.Any, tp.Any]]":
         fields = {}
         for field in dc.fields(self.dataclass):
@@ -68,7 +74,14 @@ class CreateDjangoModel(InspectDataclass):
             default = self.get_default(field)
             if default:
                 opts["default"] = default
-            fields[field.name] = django_field(**opts)
+            extra = {}
+            if extra_kwgs:
+                extra = extra_kwgs.pop(field.name, {})
+            fields[field.name] = django_field(**opts, **extra)
+        if extra_kwgs:
+            raise RuntimeError(
+                f"unconsumed extra kwgs ({extra_kwgs}) found for {self.dataclass}, please adjust!"
+            )
         return fields
 
     def generate_meta(self, unique_together: list[str] | None) -> type:
@@ -133,6 +146,9 @@ class CreateDjangoModel(InspectDataclass):
 
             return models.CharField, dict(max_length=max_length, choices=choices)
 
+        if issubclass(type_, Path):
+            return models.FileField, dict(max_length=255)
+
         try:  # try Foreign Key relation (many-to-one)
             fk_class = BACKEND_LINKER.backend_class(type_)
             assert issubclass(fk_class, models.Model)
