@@ -2,7 +2,9 @@
 import dataclasses as dc
 import enum
 import typing as tp
+from pathlib import Path
 
+from django.core.files import File
 from django.db import models
 
 from ._create_django_model import InspectDataclass
@@ -58,6 +60,11 @@ class DjangoStore:
                 val, _ = self.dump(val)
             if isinstance(val, enum.Enum):
                 val = val.value
+            if isinstance(val, Path):
+                val = File(
+                    open(val, "rb"),  # pylint: disable=consider-using-with
+                    name=val.name,
+                )
 
             # pylint: disable=protected-access
             dj_model = model._meta.get_field(key)
@@ -79,6 +86,8 @@ class DjangoStore:
             field = [field for field in dc.fields(dataclass) if field.name == key][0]
             if issubclass(field.type, enum.Enum):
                 val = field.type(val)
+            if issubclass(field.type, Path):
+                val = Path(val.url)
             # pylint: disable=protected-access
             if isinstance(dj_obj._meta.get_field(key), models.ManyToManyField):
                 val = {self.django_to_dataclass(x) for x in val.all()}
